@@ -275,16 +275,28 @@ class FeaturesAssembler(AbstractAssembler):
             advanced_signals_ts_features = buildAdvancedPriceFeatures(quotes_df=df[strats], lookback_window=lookback_window,rolling_direction=self.rolling_direction)
 
         ts_features = self.dbx.local_overwrite_and_load_pickle( folder='', subfolder=self.macro_features_directory, returns_pkl_file_name=self.ts_features_pkl_file_name, local_root_directory = Path(self.local_root_directory))
+
         ts_features_names = [col for col in list(ts_features.columns) if col!='Date']
+
         ts_features['Date'] = pd.to_datetime(ts_features['Date'])
+        ts_features = ts_features.sort_values(by=['Date'])
+
         ts_features = ts_features.set_index('Date')
         ts_features=ts_features.astype('float64')
 
+        print('Max ts fresh features date before advanced ' + str(max(ts_features.index)))
+        print('Min ts fresh features date before advanced ' + str(min(ts_features.index)))
+
         advanced_ts_features = buildAdvancedPriceFeatures(quotes_df=ts_features[ts_fresh_indices],lookback_window=lookback_window, rolling_direction=self.rolling_direction)
         print('Advanced ts fresh features size')
         print(ts_features.shape)
+        print('Max ts fresh features date ' + str(max(advanced_ts_features.index)))
+        print('Min ts fresh features date ' + str(min(advanced_ts_features.index)))
 
+        print('Advanced ts fresh features size')
         df = pd.merge(df, advanced_ts_features, how='left', left_index=True, right_index=True)
+        print('Max return date after filtering' + str(max(df.index)))
+        print('Min return date after filtering' + str(min(df.index)))
 
         for col in strats:
             df["ROC2_{}".format(col)] = df[col] / df[col].shift(2) - 1
@@ -407,19 +419,27 @@ class FeaturesAssembler(AbstractAssembler):
         np.random.seed(0)
         torch.manual_seed(0)
 
+        df_ret, strats, strat_features_names = self.preprocessReturns(tsfresh_lookback_window)
+        print('Max price date before filtering'+str(max(df_ret.index)))
+        print('Min price date before filtering'+str(min(df_ret.index)))
+
         advanced_features, advanced_features_names = self.preprocessFeatures()
 
-        df_ret, strats, strat_features_names = self.preprocessReturns(tsfresh_lookback_window)
         features_names = [col for col in list(advanced_features.columns) if col!='Date']
 
         max_date = max(advanced_features['Date'])
+        min_date = min(advanced_features['Date'])
         print('Actual max feature date '+str(max_date))
-        print('Actual computing date '+str(self.running_date))
+        print('Actual ending date '+str(self.running_date))
+
+        print('Actual min feature date '+str(min_date))
+        print('Actual starting date '+str(self.starting_date))
 
         df_ret=df_ret[df_ret.index>=self.starting_date]
         df_ret=df_ret[df_ret.index<=self.running_date]
 
         print('Max price date '+str(max(df_ret.index)))
+        print('Min price date '+str(min(df_ret.index)))
 
 
         # quotes_df=quotes_df.sort_values(by='date', ascending=True)
