@@ -75,9 +75,9 @@ def f_sharpe_signals_mix(data, w):
     return -sharpe_strat
 
 def expanding_zscore(signal_np_array=None, skipping_point = 5, signal_continuum_threshold = 20):
-    signal_np_array
     u = np.unique(signal_np_array)
-    if len(u) >= signal_continuum_threshold:
+    nb_distinct_signals = len(u)
+    if nb_distinct_signals >= signal_continuum_threshold:
         me_zscore_expanding_array = np.zeros(signal_np_array.shape)
         for i in range(len(signal_np_array)):
             if i <= skipping_point:
@@ -87,7 +87,7 @@ def expanding_zscore(signal_np_array=None, skipping_point = 5, signal_continuum_
                 me_zscore_expanding_array[i] = (signal_np_array[i] - signal_np_array[:i].mean())/std_dev
         return me_zscore_expanding_array
     else:
-        raise Exception('zscoring a non continuous signal')
+        raise Exception('zscoring a non continuous signal '+str(nb_distinct_signals))
 
 def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True, print_turnover = False, normalization = False):
     if normalization:
